==> netdata_1.18.1.orig.tar.xz: netdata-1.18.1/health/notifications/kavenegar/README.md <==
# Kavenegar

[Kavenegar](https://www.kavenegar.com/) as service for software developers, based in Iran, provides send and receive SMS, calling voice by using its APIs.

Will look like this on your Android device:

![image](https://cloud.githubusercontent.com/assets/17090999/20034652/620b6100-a39b-11e6-96af-4f83b8e830e2.png)

You will need:

1.  Signup and Login to kavenegar.com
2.  Get your APIKEY and Sender from <http://panel.kavenegar.com/client/setting/account>
3.  Fill in KAVENEGAR_API_KEY="" KAVENEGAR_SENDER=""
4.  Add the recipient phone numbers to DEFAULT_RECIPIENT_KAVENEGAR=""

Set them in `/etc/netdata/health_alarm_notify.conf` (to edit it on your system run `/etc/netdata/edit-config health_alarm_notify.conf`), like this:

```
###############################################################################
# Kavenegar (kavenegar.com) SMS options

# multiple recipients can be given like this:
#                 "09155555555 09177777777"

# enable/disable sending kavenegar SMS
SEND_KAVENEGAR="YES"

# to get an access key, after selecting and purchasing your desired service
# at http://kavenegar.com/pricing.html
# login to your account, go to your dashboard and my account are
# https://panel.kavenegar.com/Client/setting/account from API Key
# copy your api key. You can generate new API Key too.
# You can find and select kevenegar sender number from this place.

# Without an API key, Netdata cannot send KAVENEGAR text messages.
KAVENEGAR_API_KEY=""
KAVENEGAR_SENDER=""
DEFAULT_RECIPIENT_KAVENEGAR=""
```

[![analytics](https://www.google-analytics.com/collect?v=1&aip=1&t=pageview&_s=1&ds=github&dr=https%3A%2F%2Fgithub.com%2Fnetdata%2Fnetdata&dl=https%3A%2F%2Fmy-netdata.io%2Fgithub%2Fhealth%2Fnotifications%2Fkavenegar%2FREADME&_u=MAC~&cid=5792dfd7-8dc4-476b-af31-da2fdb9f93d2&tid=UA-64295674-3)](<>)

==> netdata_1.34.1.orig.tar.xz: netdata-1.34.1/health/notifications/kavenegar/README.md <==
<!--
title: "Kavenegar"
custom_edit_url: https://github.com/netdata/netdata/edit/master/health/notifications/kavenegar/README.md
-->

# Kavenegar

[Kavenegar](https://kavenegar.com/) as service for software developers, based in Iran, provides send and receive SMS, calling voice by using its APIs.

Will look like this on your Android device:

![image](https://cloud.githubusercontent.com/assets/17090999/20034652/620b6100-a39b-11e6-96af-4f83b8e830e2.png)

You will need:

1.  Signup and Login to kavenegar.com
2.  Get your APIKEY and Sender from `http://panel.kavenegar.com/client/setting/account`
3.  Fill in KAVENEGAR_API_KEY="" KAVENEGAR_SENDER=""
4.  Add the recipient phone numbers to DEFAULT_RECIPIENT_KAVENEGAR=""

Set them in `/etc/netdata/health_alarm_notify.conf` (to edit it on your system run `/etc/netdata/edit-config health_alarm_notify.conf`), like this:

```
###############################################################################
# Kavenegar (kavenegar.com) SMS options

# multiple recipients can be given like this:
#                 "09155555555 09177777777"

# enable/disable sending kavenegar SMS
SEND_KAVENEGAR="YES"

# to get an access key, after selecting and purchasing your desired service
# at http://kavenegar.com/pricing.html
# login to your account, go to your dashboard and my account are
# https://panel.kavenegar.com/Client/setting/account from API Key
# copy your api key. You can generate new API Key too.
# You can find and select kevenegar sender number from this place.

# Without an API key, Netdata cannot send KAVENEGAR text messages.
KAVENEGAR_API_KEY=""
KAVENEGAR_SENDER=""
DEFAULT_RECIPIENT_KAVENEGAR=""
```
